<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lv">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="obsolete">Dzēst</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="obsolete">Pilnekrāna režīms</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="obsolete">Slaidrāde</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="obsolete">Eksportēt</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="obsolete">Kopēt</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="obsolete">Pievienot izlasei</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="obsolete">Pagrieziet pulksteņrādītāja virzienā</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="obsolete">Pagrieziet pretēji pulksteņrādītāja virzienam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="obsolete">Iestatīt kā fona attēlu</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="obsolete">Apskatīt failu pārvaldniekā</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="obsolete">Fotoattēla informācija</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="obsolete">Atjaunot</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Nenosaukts</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Izveidot</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Jauns albums</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dzēst</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Vai tiešām vēlaties dzēst šo albumu?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Miskaste</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Izlase</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importēt</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Miskaste</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Izlase</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Vai ievelciet fotoattēlus šeit</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Importēt visu</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Importēt uz:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importēt</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Sistēmas disks</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerija</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disks ir aizņemts, nevar šobrīd izņemt</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Labi</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Jauns albums</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorēt</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Albums</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Aizvietot</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportēt</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Attēli</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumenti</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Lejupielādes</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Darbavirsma</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Mūzika</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nosaukums</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Saglabāt: </translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formāts:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kvalitāte: </translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Saglabāt</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Atlasīt citu mapi</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Labi</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>Faila nosaukums nevar būt tukšs</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>jau eksistē. Vai vēlaties to aizvietot?</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 Disks</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Tukšs %1 Disks</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 Šifrēts</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Sējums</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Saglabāt</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Exportēt Attēlus</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Tiek dzēsts...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Atjauno...</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dzēst</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Pamatinformācija</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Informācija</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Importēt</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Slaidrāde</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Pārsaukt</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportēt</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dzēst</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Ierīce</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galerija</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albumi</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Jauns albums</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Fotoattēli</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pilnekrāna režīms</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Palīdzība</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Apskatīt failu pārvaldniekā</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slaidrāde</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopēt</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Iestatīt kā fona attēlu</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pagrieziet pulksteņrādītāja virzienā</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pagrieziet pretēji pulksteņrādītāja virzienam</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Iepriekšējais</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nākamais</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Pievienot izlasei</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Noņemt no izlases</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Pārsaukt albumu</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Albums “%1” izdzēsts</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Veiksmīgi pievienots “%1”</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Veiksmīgs imports</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Imports neizdevās</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Eksports neizdevās</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Veiksmīgs eksports</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Visi Fotoattēli</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Laika skalas</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Albumi</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Pārtraukt pilnekrāna režīmu/slaidrādi</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Rādīt saīsnes</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Apskatīt</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Atlasīt visu</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Pietuvināt</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Attālināt</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Jauns albums</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Lapa uz augšu</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Lapa uz leju</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Tiek importēts...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Dzēst</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Zibspūldze</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tips</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Faila izmērs</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Izmēri</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Uzņemšanas datums</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Izmainīšanas datums</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Ekspozīcijas režīms</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Ekspozīcijas programma</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Ekspozīcijas laiks</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Apertūra</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Fokusa attālums</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Maksimālā apertūra</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mērīšanas režīms</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Baltā balanss</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Zibspuldzes kompensācija</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kameras modelis</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Objektīva modelis</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Krāsu telpa</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Birka</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Sistēmas disks</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Atlasīt</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Noņemt atlasi</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Importēts uz</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>Importēts uz</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Atjaunot</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dzēst</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Fotoattēli</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>No results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Pievienot izlasei</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pagrieziet pretēji pulksteņrādītāja virzienam</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pagrieziet pulksteņrādītāja virzienā</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Tiek importēts...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Nav meklēšanas rezultātu</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Slaidrāde</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Meklēšanas rezultāti</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Apskatīt</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pilnekrāna režīms</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportēt</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Pievienot izlasei</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Noņemt no izlases</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pagrieziet pulksteņrādītāja virzienā</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pagrieziet pretēji pulksteņrādītāja virzienam</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Apskatīt failu pārvaldniekā</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Iestatīt kā fona attēlu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dzēst</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slaidrāde</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopēt</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Fotoattēla informācija</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Pievienot albumam</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Noņemt no albuma</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Atjaunot</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Jauns albums</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Printēt</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished">dienas</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 video</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished">Pamatinformācija</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="unfinished">Izmainīšanas datums</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Tips</translation>
    </message>
    <message>
        <source>File size</source>
        <translation type="unfinished">Faila izmērs</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished">Uzņemšanas datums</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
